pub struct ReleaseTargetConfig {
pub area: Vec<String>,
pub tag_prefix: String,
pub manifests: Vec<String>,
pub workflow: Option<String>,
pub verify: Vec<String>,
pub prepare: Vec<String>,
pub completion: Option<ReleaseCompletion>,
pub publisher: Vec<String>,
}Fields
area: Vec<String>tag_prefix: Stringmanifests: Vec<String>Manifest files to bump version in (auto-detected if omitted).
workflow: Option<String>verify: Vec<String>Commands that must pass before a release is prepared.
prepare: Vec<String>Commands that mutate the isolated release worktree after version bumps.
completion: Option<ReleaseCompletion>publisher: Vec<String>Repo-owned publisher command. Loopflow appends check or publish args.