pub struct TaskAttentionSnapshot {
pub level: TaskAttentionLevel,
pub reason: String,
pub observed_at: String,
pub evidence_age_secs: Option<i64>,
pub next_owner: NextMoveOwner,
pub actions: TaskActionModel,
pub pm_completed: bool,
pub work_status: Option<WorkStatus>,
pub process: TaskProcessEvidence,
pub local_progress: LocalProgressEvidence,
pub active_pr_phase: Option<PrPhase>,
}Expand description
A Task’s shared attention projection and the evidence that proves it.
Fields
level: TaskAttentionLevelreason: Stringobserved_at: StringRFC3339 time process/workspace evidence was sampled.
evidence_age_secs: Option<i64>Age of the durable Work evidence at that sample, if Work exists.
next_owner: NextMoveOwneractions: TaskActionModelpm_completed: boolwork_status: Option<WorkStatus>process: TaskProcessEvidencelocal_progress: LocalProgressEvidenceactive_pr_phase: Option<PrPhase>Trait Implementations
Sourceimpl Clone for TaskAttentionSnapshot
impl Clone for TaskAttentionSnapshot
Sourcefn clone(&self) -> TaskAttentionSnapshot
fn clone(&self) -> TaskAttentionSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskAttentionSnapshot
impl Debug for TaskAttentionSnapshot
Sourceimpl<'de> Deserialize<'de> for TaskAttentionSnapshot
impl<'de> Deserialize<'de> for TaskAttentionSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TaskAttentionSnapshot
Sourceimpl PartialEq for TaskAttentionSnapshot
impl PartialEq for TaskAttentionSnapshot
Sourceimpl Serialize for TaskAttentionSnapshot
impl Serialize for TaskAttentionSnapshot
impl StructuralPartialEq for TaskAttentionSnapshot