Re-exports
pub use trace::hash_prompt;pub use trace::trace_enabled;pub use trace::MockResponses;pub use trace::OpTrace;pub use trace::Tracer;
Modules
- trace
- Ops tracing for parity testing.
Structs
- Abandon
Options - Combine
Options - Combine
Result - Commit
Options - Ingest
Options - Ingest
Result - Land
Options - Land
Result - Merged
Pr - A merged PR with enough context for release notes.
- Next
Options - Next
Result - Null
Progress - PrInfo
- PrOptions
- PrResult
- Rebase
Options - Release
RunResult - Release
Status Result
Enums
Traits
Functions
- abandon_
branch - bump_
version - Parse
X.Y.Zand bump the specified component. - combine_
prs - commit_
workflow - commit_
workflow_ traced - Traced version of commit_workflow for parity testing. Returns JSON trace instead of executing operations.
- create_
or_ update_ pr - current_
pr - execute_
flow_ ops - generate_
release - Generate release notes and write RELEASE_NOTES.md.
- ingest
- Fast-path ingest: pick the lowest-numbered wave item and move it to scratch/.
- land
- mark_
ready - next_
branch - rebase_
with_ recovery - release_
bump - Bump version in all manifest files for the target.
- release_
check - Check if any PRs have merged since the last tag.
- release_
notes - Generate release notes for the given version.
- release_
run - Run the full release workflow in one shot.
- release_
status - release_
tag - Create a git tag and push it to the remote.
- update_
pr